<?php

namespace FiloBlu\Flow\Model\Channel;

class Config{

    public $initialized = false;
    public $file = "map.json";
    protected $_mappedData = array();
    /**
    * @var Monolog\Logger
    */
    protected $_logger;
    protected $_channel_model;

    public function __construct(
            \FiloBlu\Flow\Helper\LoggerProvider $loggerProvider,
            \FiloBlu\Flow\Model\Channel $channelModel
    )
    {
        $this->_logger = $loggerProvider->getLogger();
        $this->_channel_model = $channelModel;
    }

    public function load($name) {

        // $name -> DB flow_channels.name
        // unique value (string)

        $this->_channel_model->load($name, 'name');

        if($this->_channel_model){
            try {
                $json_content = str_replace(array("\n", "\t", "\r"), '', $this->_channel_model->getData('data'));
                $mapped_config = json_decode($json_content,true);
                //$mapped_config->map = null;
                $this->_mappedData = $mapped_config;
                $this->initialized = true;
                $this->_logger->info(__METHOD__ . "Config ".$name. " - Loaded map json file");
            }catch(\Exception $e){
                $this->_logger->info(__METHOD__ . "Config ".$name. " - Fail to load map json file");
            }
        }else{
            $this->_logger->info(__METHOD__ . "Config ".$name. " - Model for channel data not exist for json map");
        }
        
        return $this;

    }
    
    public function getConfigData(){
        return $this->_mappedData;
    } 

    public function get($field){
        if(isset($this->_mappedData[$field])){
            return $this->_mappedData[$field];
        }
        return null;
    }

    public function getFields(){
        return array_keys($this->_mappedData);
    }

    public function checkData($data){
        if(count($data) == count($this->_mappedData)){
            return true;
        }
        return false;
    }

}
